# Security Policy

If you discover a security issue, please bring it to our attention right away!

## Reporting a Vulnerability
 
Please **DO NOT** file a public issue to report a security vulberability, instead send your report privately to **jack.hopkins@me.com**. This will help ensure that any vulnerabilities that are found can be [disclosed responsibly](https://en.wikipedia.org/wiki/Responsible_disclosure) to any affected parties.

## Supported Versions

Project versions that are currently being supported with security updates vary per project.
Please see specific project repositories for details.
If nothing is specified, only the latest major versions are supported.